using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Powertek;
using Powertek.Imaging;

namespace FFT
{
  public partial class FormMaster : Form
  {   
    public FormMaster()
    {
      InitializeComponent();
      Config.AppCaption = "FFT Tester";
      Config.AppVersion = "010";
      Config.LastDir = Application.StartupPath + "\\pics\\";
    }


    private void listDirectory(String dir)
    {
      DirectoryInfo myDir;
      FileInfo[] myFiles;
      string str;

      myDir = new DirectoryInfo(dir);
      myFiles = myDir.GetFiles();

      listBox1.Items.Clear();
      for (int k = 0; k < myFiles.Length; k++)
      {
        str = myFiles[k].Extension;
        str = str.ToLower();

        if ( str.Equals(".jpg") || str.Equals(".bmp") )
          listBox1.Items.Add(myFiles[k].Name);
      }
    }

    private void Form1_Load(object sender, EventArgs e)
    {
      Config.RegIniRead();
      listDirectory(Config.LastDir);
      toolStripStatusLabel1.Text = Config.LastDir;
    }

    private void listBox1_Click(object sender, EventArgs e)
    {
      if ((listBox1.SelectedIndex < 0) || (listBox1.Items.Count == 0))
        return;

      Bitmap bmp = (Bitmap)Bitmap.FromFile(Config.LastDir + "\\" + 
        listBox1.Items[listBox1.SelectedIndex]);

      bmp = PtBitmap.ResizeBitmapHQ(bmp, 256, 256, false);
      pictureBox1.Image = bmp;

      RunFFT();
    }

    private void Form1_FormClosing(object sender, FormClosingEventArgs e)
    {
      Config.RegIniSave();
    }


    private void RunFFT()
    {
      if (pictureBox1.Image == null)
        return;

      int threshhold = 0;

      try
      {
        threshhold = Convert.ToInt32(textBox1.Text);
      }
      catch
      {
        return;
      }
      
      Bitmap bmp1 = pictureBox1.Image.Clone() as Bitmap;
      Bitmap bmp2 = null;

      if (!checkBox1.Checked)  // color fft
      {
        PtFFTColor fftColor = new PtFFTColor();
        fftColor.Calculate(ref bmp1, out bmp1);
        pictureBox2.Image = bmp1;

        if (radioButton2.Checked)
          fftColor.RemoveDC();
        else if (radioButton3.Checked)
          fftColor.LowPassFilter(threshhold);
        else if (radioButton4.Checked)
          fftColor.HighPassFilter(threshhold, false);
        else if (radioButton5.Checked)
          fftColor.HighPassFilter(threshhold, true);

        fftColor.CalculateInv(out bmp1, out bmp2);
      }
      else // one channel fft
      {
        PtFFT fft = new PtFFT();
        fft.Calculate(ref bmp1, out bmp1, true);
        pictureBox2.Image = bmp1;

        if (radioButton2.Checked)
          fft.RemoveDC();
        else if (radioButton3.Checked)
          fft.LowPassFilter(threshhold);
        else if (radioButton4.Checked)
          fft.HighPassFilter(threshhold, false);
        else if (radioButton5.Checked)
          fft.HighPassFilter(threshhold, true);

        fft.CalculateInv(out bmp1, out bmp2);
      }
      

      pictureBox3.Image = bmp1;
      pictureBox3.Refresh();
      pictureBox4.Image = bmp2;
      pictureBox4.Refresh();
    }


    private void exitToolStripMenuItem_Click(object sender, EventArgs e)
    {
      this.Close();
    }

    private void selectDirectoryToolStripMenuItem_Click(object sender, EventArgs e)
    {
      FolderBrowserDialog dialog = new FolderBrowserDialog();
      dialog.ShowNewFolderButton = false;
      dialog.Description = "Bitte whlen Sie ein Verzeichnis mit JPEG-Dateien!";
      dialog.SelectedPath = Config.LastDir;

      if (dialog.ShowDialog() == System.Windows.Forms.DialogResult.OK)
      {
        Config.LastDir = dialog.SelectedPath;
        toolStripStatusLabel1.Text = Config.LastDir;
        listDirectory(Config.LastDir);
      }
    }

    private void inputHandler(object sender, KeyPressEventArgs e)
    {
      if (!Char.IsDigit(e.KeyChar) && 
          e.KeyChar != (char)8 && e.KeyChar != (char)13)
      {
        e.Handled = true;   // forget this input
      }
    }

    private void radioButton1_MouseUp(object sender, MouseEventArgs e)
    {
      RunFFT();
    }


    private void checkBox1_MouseUp(object sender, MouseEventArgs e)
    {
      RunFFT();
    }

    private void textBox1_KeyDown(object sender, KeyEventArgs e)
    {
      if (e.KeyCode == Keys.Return)
        RunFFT();
    }


  }
}